#!/usr/bin/env python3
# coding: utf-8
# Copyright 2024 Huawei Technologies Co., Ltd
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
# ===========================================================================
EOL_CARD = ["A300-3000", "A300-3010"]
EOL_MODEL = ["Atlas 200I Soc A1"]
CARD_DICT = {
    "A300i-pro": [
        "Ubuntu_20.04_aarch64",
        "Ubuntu_20.04_x86_64",
        "OpenEuler_20.03LTS_aarch64",
        "OpenEuler_20.03LTS_x86_64",
        "OpenEuler_22.03LTS_aarch64",
        "OpenEuler_22.03LTS_x86_64",
        "Kylin_V10Tercel_aarch64",
        "Kylin_V10Tercel_x86_64",
        "CentOS_7.6_aarch64",
        "CentOS_7.6_x86_64",
        "EulerOS_2.9_aarch64",
        "EulerOS_2.9_x86_64",
        "EulerOS_2.10_aarch64",
        "EulerOS_2.10_x86_64"
    ],
    "A300i-duo": [
        "Ubuntu_20.04_aarch64",
        "Ubuntu_20.04_x86_64"
    ],
    "A200i-a2": [
        "Kylin_V10_aarch64",
    ],
    "A300T-9000": [
        "Ubuntu_18.04_x86_64",
        "Ubuntu_20.04_aarch64",
        "Ubuntu_20.04_x86_64",
        "OpenEuler_20.03LTS_aarch64",
        "OpenEuler_20.03LTS_x86_64",
        "OpenEuler_22.03LTS_aarch64",
        "OpenEuler_22.03LTS_x86_64",
        "Kylin_V10Tercel_aarch64",
        "Kylin_V10Tercel_x86_64",
        "Kylin_V10Sword_aarch64",
        "CentOS_7.6_aarch64",
        "CentOS_7.6_x86_64",
        "UOS_20-1020e_aarch64",
        "EulerOS_2.8_aarch64",
        "EulerOS_2.9_aarch64",
        "EulerOS_2.9_x86_64",
        "EulerOS_2.10_aarch64",
        "EulerOS_2.10_x86_64",
    ],
    "A900T": [
        "BCLinux_21.10_aarch64",
        "CTyunOS_22.06_aarch64",
        "EulerOS_2.10_aarch64",
        "EulerOS_2.10_x86_64",
        "OpenEuler_22.03LTS_aarch64",
        "OpenEuler_22.03LTS_x86_64",
        "CentOS_7.6_aarch64",
        "CentOS_7.6_x86_64",
        "Kylin_V10_aarch64",
        "Kylin_V10Sword_aarch64",
        "UOS_20-1050e_aarch64",
        "Ubuntu_22.04_aarch64",
        "Ubuntu_22.04_x86_64",
        "CULinux_3.0_aarch64"
    ],
    "A300t-a2": [
        "OpenEuler_22.03LTS_aarch64",
        "OpenEuler_22.03LTS_x86_64",
        "Ubuntu_22.04_aarch64",
        "Ubuntu_22.04_x86_64",
    ],
    "Atlas 800I A2": [
        "OpenEuler_22.03LTS_aarch64",
        "OpenEuler_22.03LTS_x86_64",
        "Ubuntu_22.04_aarch64",
        "Ubuntu_22.04_x86_64"
    ]
}
MODEL_TAGS_NOT_SUPPORT = {
    "Atlas 500 Pro (Model 3000)": [
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "mindio",
        "resilience-controller",
        "ascend-operator"
    ],
    "Atlas 500 Pro(Model 3000)": [
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "mindio",
        "resilience-controller",
        "ascend-operator"
    ]
}
OS_ARCH_TAGS_SUPPORT = {
    "CentOS_7.6_aarch64": [
        "atlasedge",
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "mindio",
        "resilience-controller",
        "ascend-operator",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "vmhost"
    ],
    "CentOS_7.6_x86_64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "mindio",
        "resilience-controller",
        "ascend-operator",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "vmhost"
    ],
    "BCLinux_21.10_aarch64": [
        "docker_images",
        "driver",
        "firmware",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "vmhost"
    ],
    "CTyunOS_22.06_aarch64": [
        "docker_images",
        "driver",
        "firmware",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "vmhost",
        "volcano",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "ascend-operator"
    ],
    "CTyunOS_22.06_x86_64": [
        "docker_images",
        "driver",
        "firmware",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "vmhost",
        "volcano",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "ascend-operator"
    ],
    "EulerOS_2.8_aarch64": [
        "atlasedge",
        "docker_images",
        "driver",
        "firmware",
        "ha",
        "ief",
        "kernels",
        "mindspore",
        "mindstudio",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "edge",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "vmhost"
    ],
    "EulerOS_2.9_aarch64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "vmhost"
    ],
    "EulerOS_2.9_x86_64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "vmhost"
    ],
    "EulerOS_2.10_x86_64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "vmhost"
    ],
    "EulerOS_2.10_aarch64": [
        "docker_images",
        "driver",
        "firmware",
        "ha",
        "ief",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "vmhost"
    ],
    "Kylin_V10_aarch64": [
        "docker_images",
        "driver",
        "firmware",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "vmhost"
    ],
    "Kylin_V10Tercel_aarch64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "vmhost"
    ],
    "Kylin_V10Tercel_x86_64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "vmhost"
    ],
    "Kylin_V10Sword_aarch64": [
        "docker_images",
        "driver",
        "firmware",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "mindspore",
        "mindio",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "vmhost"
    ],
    "OpenEuler_20.03LTS_aarch64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "mindio",
        "resilience-controller",
        "ascend-operator",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "vmhost"
    ],
    "OpenEuler_20.03LTS_x86_64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "mindio",
        "resilience-controller",
        "ascend-operator",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "vmhost"
    ],
    "OpenEuler_22.03LTS_aarch64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "mindstudio",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "mindio",
        "resilience-controller",
        "ascend-operator",
        "mef",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "vmhost"
    ],
    "OpenEuler_22.03LTS_x86_64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "mindstudio",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "mindio",
        "resilience-controller",
        "ascend-operator",
        "mef",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "vmhost"
    ],
    "Ubuntu_18.04_aarch64": [
        "atlasedge",
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "mindstudio",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "mindio",
        "resilience-controller",
        "ascend-operator",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "vmhost"
    ],
    "Ubuntu_18.04_x86_64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "mindstudio",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "mindio",
        "resilience-controller",
        "ascend-operator",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "vmhost"
    ],
    "Ubuntu_20.04_aarch64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "mindio",
        "resilience-controller",
        "ascend-operator",
        "mef",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "vmhost"
    ],
    "Ubuntu_20.04_x86_64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "mindio",
        "resilience-controller",
        "ascend-operator",
        "mef",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "vmhost"
    ],
    "Ubuntu_22.04_aarch64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "mindstudio",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "resilience-controller",
        "ascend-operator",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "vmhost"
    ],
    "Ubuntu_22.04_x86_64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "mindstudio",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "resilience-controller",
        "ascend-operator",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "vmhost"
    ],
    "UOS_20-1020e_aarch64": [
        "atlasedge",
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "vmhost",
        "mindio"
    ],
    "UOS_20-1050e_aarch64": [
        "docker_images",
        "driver",
        "firmware",
        "ief",
        "kernels",
        "mindspore",
        "nnae",
        "nnrt",
        "npu",
        "python",
        "pytorch",
        "sys_pkg",
        "tensorflow",
        "tfplugin",
        "toolbox",
        "toolkit",
        "auto",
        "dl",
        "volcano",
        "hccl-controller",
        "ascend-device-plugin",
        "noded",
        "npu-exporter",
        "ascend-docker-runtime",
        "resilience-controller",
        "ascend-operator",
        "mindspore",
        "offline_dev",
        "offline_run",
        "pytorch_dev",
        "pytorch_run",
        "tensorflow_dev",
        "tensorflow_run",
        "vmhost",
    ],
}
